Tutorial
========

In this tutorial the main features and usecases of LattPy are discussed and explained.
Throughout the tutorial the packages ``numpy`` and ``matplotlib`` are used. `LattPy`
is imported as ``lp`` - using a similar alias as the other scientific computing libaries:

>>> import numpy as np
>>> import matplotlib.pyplot as plt
>>> import lattpy as lp


.. toctree::
   :maxdepth: 3
   :numbered:

   configuration
   general
   finite
